@@ -14,7 +14,7 @@ pub struct CpuTime {
 impl CpuTime {
     pub fn new(header: Option<String>) -> Self {
         let header = header.unwrap_or_else(|| String::from("CPU Time"));
-        let unit = String::from("");
+        let unit = String::new();
         CpuTime {
             fmt_contents: HashMap::new(),
             raw_contents: HashMap::new(),
@@ -29,7 +29,7 @@ impl CpuTime {
 impl Column for CpuTime {
     fn add(&mut self, proc: &ProcessInfo) {
         let time_sec = (proc.curr_proc.stat().utime + proc.curr_proc.stat().stime)
-            / procfs::ticks_per_second().unwrap_or(100) as u64;
+            / procfs::ticks_per_second().unwrap_or(100);
 
         let fmt_content = util::parse_time(time_sec);
         let raw_content = time_sec;
