@@ -33,12 +33,11 @@ impl Column for UsageCpu {
 
         let curr_time = curr_stat.utime + curr_stat.stime;
         let prev_time = prev_stat.utime + prev_stat.stime;
-        let usage_ms =
-            (curr_time - prev_time) * 1000 / procfs::ticks_per_second().unwrap_or(100) as u64;
+        let usage_ms = (curr_time - prev_time) * 1000 / procfs::ticks_per_second().unwrap_or(100);
         let interval_ms = proc.interval.as_secs() * 1000 + u64::from(proc.interval.subsec_millis());
         let usage = usage_ms as f64 * 100.0 / interval_ms as f64;
 
-        let fmt_content = format!("{:.1}", usage);
+        let fmt_content = format!("{usage:.1}");
         let raw_content = (usage * 1000.0) as u32;
 
         self.fmt_contents.insert(proc.pid, fmt_content);
