@@ -4,7 +4,7 @@ use serde_derive::{Deserialize, Serialize};
 use std::str::FromStr;
 
 // ---------------------------------------------------------------------------------------------------------------------
-// Functions for serde defalut
+// Functions for serde default
 // ---------------------------------------------------------------------------------------------------------------------
 
 fn default_true() -> bool {
@@ -167,7 +167,7 @@ fn serialize_color(c: &ConfigColor) -> String {
         ConfigColor::Magenta => "Magenta".to_string(),
         ConfigColor::Cyan => "Cyan".to_string(),
         ConfigColor::White => "White".to_string(),
-        ConfigColor::Color256(x) => format!("{}", x),
+        ConfigColor::Color256(x) => format!("{x}"),
     }
 }
 
@@ -202,7 +202,7 @@ fn serialize_color_by_theme(c: &ConfigColorByTheme) -> String {
     } else {
         let dark = serialize_color(dark);
         let light = serialize_color(light);
-        format!("{}|{}", dark, light)
+        format!("{dark}|{light}")
     }
 }
 
@@ -619,7 +619,8 @@ pub struct ConfigDocker {
 impl Default for ConfigDocker {
     fn default() -> Self {
         ConfigDocker {
-            path: String::from("unix:///var/run/docker.sock"),
+            path: std::env::var("DOCKER_HOST")
+                .unwrap_or(String::from("unix:///var/run/docker.sock")),
         }
     }
 }
