@@ -196,12 +196,12 @@ fn get_config() -> Result<Config, Error> {
     let cfg_path = dot_cfg_path.or(app_cfg_path).or(xdg_cfg_path);
 
     let config: Config = if let Some(path) = cfg_path {
-        let mut f = fs::File::open(&path).context(format!("failed to open file ({:?})", path))?;
+        let mut f = fs::File::open(&path).context(format!("failed to open file ({path:?})"))?;
         let mut s = String::new();
         f.read_to_string(&mut s)
-            .context(format!("failed to read file ({:?})", path))?;
+            .context(format!("failed to read file ({path:?})"))?;
         let c = toml::from_str(&s);
-        check_old_config(&s, c).context(format!("failed to parse toml ({:?})", path))?
+        check_old_config(&s, c).context(format!("failed to parse toml ({path:?})"))?
     } else {
         toml::from_str(CONFIG_DEFAULT).unwrap()
     };
@@ -268,7 +268,7 @@ fn run() -> Result<(), Error> {
             Shell::Zsh => "./_procs",
             x => return Err(anyhow!("unknown shell type: {}", x)),
         };
-        println!("completion file is generated: {}", path);
+        println!("completion file is generated: {path}");
         Ok(())
     } else if let Some(shell) = opt.completion_out {
         //Opt::clap().gen_completions_to("procs", shell, &mut stdout());
@@ -281,9 +281,9 @@ fn run() -> Result<(), Error> {
                 Some(n) => (n * 1000.0).round() as u64,
                 None => 1000,
             };
-            run_watch(&opt, &config, interval)
+            run_watch(&mut opt, &config, interval)
         } else {
-            run_default(&opt, &config)
+            run_default(&mut opt, &config)
         }
     }
 }
@@ -291,7 +291,7 @@ fn run() -> Result<(), Error> {
 fn run_config() -> Result<(), Error> {
     let config: Config = toml::from_str(CONFIG_DEFAULT).unwrap();
     let toml = toml::to_string(&config)?;
-    println!("{}", toml);
+    println!("{toml}");
     Ok(())
 }
 
@@ -320,11 +320,11 @@ fn run_list() -> Result<(), Error> {
 }
 
 #[cfg_attr(tarpaulin, skip)]
-fn run_watch(opt: &Opt, config: &Config, interval: u64) -> Result<(), Error> {
+fn run_watch(opt: &mut Opt, config: &Config, interval: u64) -> Result<(), Error> {
     Watcher::start(opt, config, interval)
 }
 
-fn run_default(opt: &Opt, config: &Config) -> Result<(), Error> {
+fn run_default(opt: &mut Opt, config: &Config) -> Result<(), Error> {
     let mut time = Instant::now();
 
     let theme = get_theme(opt, config);
@@ -367,8 +367,8 @@ mod tests {
         config.display.theme = ConfigTheme::Dark;
 
         let args = vec!["procs"];
-        let opt = Opt::parse_from(args.iter());
-        let ret = run_default(&opt, &config);
+        let mut opt = Opt::parse_from(args.iter());
+        let ret = run_default(&mut opt, &config);
         assert!(ret.is_ok());
     }
 
@@ -379,40 +379,40 @@ mod tests {
         config.display.theme = ConfigTheme::Dark;
 
         let args = vec!["procs", "root"];
-        let opt = Opt::parse_from(args.iter());
-        let ret = run_default(&opt, &config);
+        let mut opt = Opt::parse_from(args.iter());
+        let ret = run_default(&mut opt, &config);
         assert!(ret.is_ok());
 
         let args = vec!["procs", "1"];
-        let opt = Opt::parse_from(args.iter());
-        let ret = run_default(&opt, &config);
+        let mut opt = Opt::parse_from(args.iter());
+        let ret = run_default(&mut opt, &config);
         assert!(ret.is_ok());
 
         let args = vec!["procs", "--or", "root", "1"];
-        let opt = Opt::parse_from(args.iter());
-        let ret = run_default(&opt, &config);
+        let mut opt = Opt::parse_from(args.iter());
+        let ret = run_default(&mut opt, &config);
         assert!(ret.is_ok());
 
         let args = vec!["procs", "--and", "root", "1"];
-        let opt = Opt::parse_from(args.iter());
-        let ret = run_default(&opt, &config);
+        let mut opt = Opt::parse_from(args.iter());
+        let ret = run_default(&mut opt, &config);
         assert!(ret.is_ok());
 
         let args = vec!["procs", "--nor", "root", "1"];
-        let opt = Opt::parse_from(args.iter());
-        let ret = run_default(&opt, &config);
+        let mut opt = Opt::parse_from(args.iter());
+        let ret = run_default(&mut opt, &config);
         assert!(ret.is_ok());
 
         let args = vec!["procs", "--nand", "root", "1"];
-        let opt = Opt::parse_from(args.iter());
-        let ret = run_default(&opt, &config);
+        let mut opt = Opt::parse_from(args.iter());
+        let ret = run_default(&mut opt, &config);
         assert!(ret.is_ok());
 
         config.search.nonnumeric_search = ConfigSearchKind::Exact;
         config.search.numeric_search = ConfigSearchKind::Partial;
         let args = vec!["procs", "root", "1"];
-        let opt = Opt::parse_from(args.iter());
-        let ret = run_default(&opt, &config);
+        let mut opt = Opt::parse_from(args.iter());
+        let ret = run_default(&mut opt, &config);
         assert!(ret.is_ok());
     }
 
@@ -435,9 +435,9 @@ mod tests {
         config.display.theme = ConfigTheme::Dark;
 
         let args = vec!["procs"];
-        let opt = Opt::parse_from(args.iter());
+        let mut opt = Opt::parse_from(args.iter());
         config.pager.mode = ConfigPagerMode::Disable;
-        let ret = run_default(&opt, &config);
+        let ret = run_default(&mut opt, &config);
         assert!(ret.is_ok());
     }
 
@@ -448,8 +448,8 @@ mod tests {
         config.display.theme = ConfigTheme::Dark;
 
         let args = vec!["procs", "--insert", "ppid"];
-        let opt = Opt::parse_from(args.iter());
-        let ret = run_default(&opt, &config);
+        let mut opt = Opt::parse_from(args.iter());
+        let ret = run_default(&mut opt, &config);
         assert!(ret.is_ok());
     }
 
@@ -460,13 +460,13 @@ mod tests {
         config.display.theme = ConfigTheme::Dark;
 
         let args = vec!["procs", "--sorta", "cpu"];
-        let opt = Opt::parse_from(args.iter());
-        let ret = run_default(&opt, &config);
+        let mut opt = Opt::parse_from(args.iter());
+        let ret = run_default(&mut opt, &config);
         assert!(ret.is_ok());
 
         let args = vec!["procs", "--sortd", "cpu"];
-        let opt = Opt::parse_from(args.iter());
-        let ret = run_default(&opt, &config);
+        let mut opt = Opt::parse_from(args.iter());
+        let ret = run_default(&mut opt, &config);
         assert!(ret.is_ok());
     }
 
@@ -477,8 +477,8 @@ mod tests {
         config.display.theme = ConfigTheme::Dark;
 
         let args = vec!["procs", "--tree"];
-        let opt = Opt::parse_from(args.iter());
-        let ret = run_default(&opt, &config);
+        let mut opt = Opt::parse_from(args.iter());
+        let ret = run_default(&mut opt, &config);
         assert!(ret.is_ok());
     }
 
@@ -492,8 +492,8 @@ mod tests {
         let _udp = std::net::UdpSocket::bind("127.0.0.1:10000");
 
         let args = vec!["procs"];
-        let opt = Opt::parse_from(args.iter());
-        let ret = run_default(&opt, &config);
+        let mut opt = Opt::parse_from(args.iter());
+        let ret = run_default(&mut opt, &config);
         assert!(ret.is_ok());
     }
 }
