@@ -31,7 +31,7 @@ pub struct View {
 }
 
 impl View {
-    pub fn new(opt: &Opt, config: &Config, clear_by_line: bool) -> Result<Self, Error> {
+    pub fn new(opt: &mut Opt, config: &Config, clear_by_line: bool) -> Result<Self, Error> {
         let mut slot_idx = 0;
         let mut columns = Vec::new();
         let mut only_kind_found = false;
@@ -48,6 +48,16 @@ impl View {
             header: None,
         };
 
+        // Adding the sort column to inserts if not already present
+        match (&opt.sorta, &opt.sortd) {
+            (_, Some(col)) | (Some(col), _) => {
+                if !opt.insert.contains(col) {
+                    opt.insert.push(col.clone());
+                }
+            }
+            _ => {}
+        }
+
         // Add default TreeSlot if there is not TreeSlot in config
         let config_columns = if config
             .columns
@@ -420,7 +430,7 @@ impl View {
     }
 
     fn display_header(&self, config: &Config, theme: &ConfigTheme) -> Result<(), Error> {
-        let mut row = String::from("");
+        let mut row = String::new();
         for (i, c) in self.columns.iter().enumerate() {
             if c.visible {
                 let order = if i == self.sort_info.idx {
@@ -447,7 +457,7 @@ impl View {
     }
 
     fn display_unit(&self, config: &Config, theme: &ConfigTheme) -> Result<(), Error> {
-        let mut row = String::from("");
+        let mut row = String::new();
         for c in &self.columns {
             if c.visible {
                 row = format!(
@@ -475,7 +485,7 @@ impl View {
         theme: &ConfigTheme,
         auxiliary: bool,
     ) -> Result<(), Error> {
-        let mut row = String::from("");
+        let mut row = String::new();
         for c in &self.columns {
             if c.visible {
                 row = format!(
@@ -584,7 +594,7 @@ impl View {
     #[cfg(not(any(target_os = "windows", any(target_os = "linux", target_os = "android"))))]
     fn pager(config: &Config) {
         if let Some(ref pager) = config.pager.command {
-            Pager::with_pager(&pager).setup();
+            Pager::with_pager(pager).setup();
         } else if which::which("less").is_ok() {
             Pager::with_pager("less -SR").setup();
         } else {
@@ -597,11 +607,11 @@ impl View {
         if let Some(ref pager) = config.pager.command {
             Pager::with_pager(pager)
                 // workaround for default less charset is "ascii" on some environments (ex. Ubuntu)
-                .pager_envs(&["LESSCHARSET=utf-8\0"])
+                .pager_envs(["LESSCHARSET=utf-8\0"])
                 .setup();
         } else if which::which("less").is_ok() {
             Pager::with_pager("less -SR")
-                .pager_envs(&["LESSCHARSET=utf-8\0"])
+                .pager_envs(["LESSCHARSET=utf-8\0"])
                 .setup();
         } else {
             Pager::with_pager("more -f").setup();
